ALTER PROCEDURE HM.IsDocumentAsPeriodicSaleReport @DKid INT
AS
BEGIN
    /*
######################################################################
#          ZMIANY ROWNOCZESNIE W DWOCH MIEJSCACH                     #
#               PROCEDURE HM.IsDocumentAsPeriodicSaleReport          #
#               WORD      SendAggregated( ... )                      #
######################################################################
Procedura sprawdzajca warunki czy paragon si kwalifikuje do paragonu zbiorczego
1) Spradzamy czy jest charakteru paragon lub korekta paragonu
2) Czy data sprzeday jest starsza ni 2020-10-01
3) Paragon z NIPem nabywcy tylko do kwoty okreslonej parametrem
4) jesli anulowane to tylko anulowane faktura (warto 3)
5) Nie bieemy dokumentw w buforze
6) W przypadku korekty nie bieemy daty sprzeday, bieemy dat wystawienia dla generowanie raportu
*/

    --Zmienne potrzebne do sprawdze
    DECLARE @PeriodicSalesReportStartDate DATE = '2020-10-01';
    DECLARE @DocumentSaleDate DATE,
            @DocCharakter INT,
            @RecipientWorkParameter DECIMAL(10, 2),
            @DocumentGrossValue DECIMAL(10, 2),
            @DocumentCanecled INT,
            @IsContractorWithNIP BIT,
			@bufor SMALLINT,
            @aktywny SMALLINT,
			@flag SMALLINT;

    --Odczyt parametru
    SELECT @RecipientWorkParameter = ISNULL( ( SELECT TRY_CAST(opis AS DECIMAL(10, 2))
                                                 FROM HM.ZZ
                                                WHERE id2 = 1288
                                             ),
                                             0.0
                                           );
    SELECT @DocumentSaleDate = CASE WHEN subtyp=50 THEN datasp WHEN dok.subtyp=51 THEN dok.data ELSE dok.datasp end,
           @DocCharakter = subtyp,
           @DocumentGrossValue = walBrutto,
		   @bufor= dok.bufor,
           @aktywny= dok.aktywny,
           @IsContractorWithNIP = CASE 
									  WHEN contractor.nip LIKE 'P:%' THEN 0
                                      WHEN contractor.nip = '' THEN 0
                                      ELSE 1
                                  END,
           @DocumentCanecled = CASE WHEN dok.anulowany <> 0 AND dok.anulowany <> 3 THEN 1 ELSE 0 END
    FROM HM.DK dok
        LEFT JOIN HM.AD contractor
            ON dok.khadid = contractor.id
    WHERE dok.id = @DKid;
	SET @flag = (SELECT flag FROM HM.DK WHERE id = @DKid)
	IF((@flag & 0x0080) = 0) -- jestli metoda memorialowa to bierzemy date wejscia do rejestru 	
		SET @DocumentSaleDate = (SELECT datarej FROM HM.DK WHERE id = @DKid)

    -- aktywna wystawiona korekta paragonu bezwarunkowo wysylana zbiorczo
    IF (((@DocCharakter = 50) AND
         (@DocumentSaleDate >= @PeriodicSalesReportStartDate) AND
         (@IsContractorWithNIP = 0 OR ABS(@DocumentGrossValue) > @RecipientWorkParameter) AND
         (@DocumentCanecled = 0)
        )
        OR
        (@DocCharakter = 51)
       )
       AND @bufor=0 AND @aktywny = 1
    BEGIN
        EXEC HM.GeneratePeriodicSaleReport @date = @DocumentSaleDate,
                                           @dkid = @DKid;
    END;
	ELSE
	BEGIN
		DECLARE @idPeriodicSaleReport INT
		SELECT @idPeriodicSaleReport = IdPeriodicSaleReport FROM DK WHERE id = @DKid
		UPDATE HM.DK SET IdPeriodicSaleReport = NULL WHERE id  = @DKid
		IF ((SELECT COUNT(id) FROM hm.DK WHERE IdPeriodicSaleReport = @idPeriodicSaleReport) = 0)
			DELETE FROM hm.PeriodicSaleReports WHERE Id = @idPeriodicSaleReport
		ELSE
			EXEC hm.RecalculatePeriodicSaleReport NULL, @idPeriodicSaleReport
	END
END;